@@ -16,6 +16,7 @@ class BrowserBridge(DatabaseMixin, Bridge):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.elements = []
+        self.browser_pid = None
 
     @property
     def web_driver(self):
@@ -75,6 +76,8 @@ class BrowserBridge(DatabaseMixin, Bridge):
         if is_new_session:
             self.web_driver = WebDriver()
             self.web_driver.start(preferred_browser=preferred_browser)
+            self.browser_pid = self.web_driver.browser_pid
+            self.logger.debug("The Browser PID (at start): %s", self.browser_pid)
         if self.ctx.selected:
             locator_db = self.get_locators()
             self.logger.debug("Editing locator: %s", locator_db[self.ctx.selected])
@@ -104,8 +107,10 @@ class BrowserBridge(DatabaseMixin, Bridge):
         kill_all = only_kill_browser is False and only_kill_app is False
         if kill_all:
             self.logger.warning("Using force kill to close the app window")
-            # pylint: disable=protected-access
-            os._exit(os.EX_OK)
+            if self.web_driver:
+                self.logger.debug("Destroying web driver...")
+                self.web_driver.stop()
+            os._exit(0)  # pylint: disable=protected-access
         if only_kill_app:
             self.logger.debug("Destroying app window...")
             self.close()
