@@ -21,6 +21,20 @@ from selenium.webdriver import ChromeOptions, Remote  # type: ignore
 from selenium.webdriver.common.by import By
 
 
+class WebDriverExceptions(Exception):
+    def __init__(
+        self,
+        msg: Optional[str] = None,
+        errors: Optional[Dict[str, WebDriverException]] = None,
+    ):
+        super().__init__()
+        self.msg = msg or ""
+        self.errors = errors or {}
+
+    def __str__(self) -> str:
+        return f"{self.msg}" + ", ".join(self.errors.keys())
+
+
 def load_resource(filename):
     path = Path(__file__).parent / "static" / "resources" / str(filename)
     with open(path, "r", encoding="utf-8") as file:
@@ -121,6 +135,12 @@ class WebDriver:
         self._load_resources()
         self._is_recording: bool = False
 
+    @property
+    def browser_pid(self):
+        if not self.selenium:
+            return None
+        return self.selenium.service.process.pid
+
     @classmethod
     def from_remote(cls, executor_url, session_id, handle):
         # Override new session command to prevent spawning windows
@@ -242,6 +262,7 @@ class WebDriver:
             if preferred_browser is not None
             else webdriver.get_browser_order()
         )
+        errors = {}
         for browser in browsers:
             if browser.lower() == "chrome":
                 kwargs = {"chrome_options": chrome_options()}
@@ -269,10 +290,12 @@ class WebDriver:
                 return _create_driver()
             except WebDriverException as exc:
                 self.logger.warning("Failed to start '%s': %s", browser, exc)
-            except Exception:  # pylint: disable=broad-except
+                errors[browser] = exc
+            except Exception as exc:  # pylint: disable=broad-except
                 self.logger.error("Unhandled exception:\n%s", traceback.format_exc())
+                errors[browser] = WebDriverException(f"Unhandled exception: {exc}")
 
-        raise ValueError("No valid browser found")
+        raise WebDriverExceptions("No available webdriver found for ", errors)
 
     def _to_finder(self, strategy):
         strategy = str(strategy).lower()
