@@ -79,6 +79,7 @@ class WindowsDriver:
         self._windows_elements = WindowsElements()
         self._active_window = ""
         self.queue = Queue()
+        self._active_listener = None
 
     def _construct_locator(
         self,
@@ -184,16 +185,20 @@ class WindowsDriver:
             )
             self._focus_active_window(active_window)
             locators: List[WindowsLocator] = []
-            listener = Listener(on_click=self._on_click)
+            self._active_listener = Listener(on_click=self._on_click)
             try:
-                listener.start()
+                self._active_listener.start()
                 locators = self.queue.get(block=True, timeout=PICK_TIMEOUT)
             except Empty:
                 self.logger.info("Locator selection timeout")
             finally:
-                listener.stop()
+                self._active_listener.stop()
         return locators
 
+    def stop_pick(self):
+        if self._active_listener:
+            self._active_listener.stop()
+
     def validate(self, window: str, value: str) -> MatchedWindowsLocators:
         self.logger.info("Validate=%s, %s", window, value)
         locators: MatchedWindowsLocators = {"matches": []}
